searchData={"items":[{"type":"module","title":"EctoCache","doc":"Implements an in-memory process to cache the results of database queries.","ref":"EctoCache.html"},{"type":"function","title":"EctoCache.cache/3","doc":"Gets the value of `key` from the cache, if available. If the value has not\nbeen cached yet or it has expired, executes the `fun` function and cache\ntheir result.\n\nYou can set `lifetime` to the number of seconds you want the value to be\navailable or to `infinity` so that it never expires. Every time the `key`\nvalue is read, the availability time is reset again to `lifetime`.","ref":"EctoCache.html#cache/3"},{"type":"function","title":"Example - EctoCache.cache/3","doc":"iex> EctoCache.cache(:posts, &Repo.all(Post), 600)\n    [%Post{}, ...]","ref":"EctoCache.html#cache/3-example"},{"type":"function","title":"EctoCache.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"EctoCache.html#child_spec/1"},{"type":"function","title":"EctoCache.delete/1","doc":"Deletes the cached `key` value.\n\nUse this function when the cached values have changed and you want to disable\nthe cache to avoid reading outdated data.\n\nThis function always returns `:ok` regardless of whether or not a cached value\nexists for the `key`.","ref":"EctoCache.html#delete/1"},{"type":"function","title":"Examples - EctoCache.delete/1","doc":"iex> EctoCache.delete(:posts)\n    :ok","ref":"EctoCache.html#delete/1-examples"},{"type":"function","title":"EctoCache.delete/2","doc":"Same as `EctoCache.delete/1` but designed to be used in a pipeline as a\nresult of a `Ecto.Repo` write operation.\n\nThis function integrates with `Ecto.Repo.insert/2`, `Ecto.Repo.update/2` and\n`Ecto.Repo.delete/2`, deleting the cache _only_ if the operation was carried\nout and returning the result of the database operation.","ref":"EctoCache.html#delete/2"},{"type":"function","title":"Examples - EctoCache.delete/2","doc":"iex> Repo.insert(post) |> EctoCache.delete(:posts)\n    {:ok, %Post{}}\n\n    iex> Repo.update(post) |> EctoCache.delete(:posts)\n    {:ok, %Post{}}\n\n    iex> Repo.delete(post) |> EctoCache.delete(:posts)\n    {:ok, %Post{}}","ref":"EctoCache.html#delete/2-examples"},{"type":"function","title":"EctoCache.start_link/1","doc":"Starts the `EctoCache` process.\n\nYou should not use this function directly. Instead add `EctoCache` to your\nsupervision tree as explained in the module documentation.","ref":"EctoCache.html#start_link/1"},{"type":"opaque","title":"EctoCache.t/0","doc":"","ref":"EctoCache.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v1.0.0 (2023-01-22) - Changelog","doc":"* This is the first production ready release.","ref":"changelog.html#v1-0-0-2023-01-22"},{"type":"extras","title":"EctoCache","doc":"# EctoCache\n\n`EctoCache` is a process that implements an in-memory cache to store the\nresults of database queries with `Ecto`. It is ideal for small lists of data\nthat are constantly being read from the database and change very little such as\na list of countries or product categories in an e-commerce.","ref":"readme.html"},{"type":"extras","title":"Setup - EctoCache","doc":"Add `ecto_cache` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ecto_cache, \"~> 0.1.0\"}\n  ]\nend\n```\n\nRun `mix deps.get` to install the dependencies.\n\nAdd `ecto_cache` as a worker to the supervision tree in your `application.ex`\ninside the `start/2` function:\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    # ...\n    EctoCache\n  ]\n\n  # ...\nend\n```","ref":"readme.html#setup"}],"content_type":"text/markdown"}